==> packageinstaller-pkglist_0.3.29.tar.xz: packageinstaller-pkglist/Romansh_Default_Firefox_esr.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Romansh_Default_Firefox_esr
</name>

<description>
   <am>Romansh localisation of Firefox ESR</am>
   <ar>Romansh localisation of Firefox ESR</ar>
   <be>Romansh localisation of Firefox ESR</be>
   <bg>Romansh localisation of Firefox ESR</bg>
   <bn>Romansh localisation of Firefox ESR</bn>
   <ca>Romansh localisation of Firefox ESR</ca>
   <cs>Romansh localisation of Firefox ESR</cs>
   <da>Romansh localisation of Firefox ESR</da>
   <de>Schweizerische Lokalisation für die Sprache “Rätoromanisch” von “Firefox ESR”</de>
   <el>Romansh για Firefox ESR</el>
   <en>Romansh localisation of Firefox ESR</en>
   <es_ES>Romansh localisation of Firefox ESR</es_ES>
   <es>Localización Romanche de Firefox ESR</es>
   <et>Romansh localisation of Firefox ESR</et>
   <eu>Romansh localisation of Firefox ESR</eu>
   <fa>Romansh localisation of Firefox ESR</fa>
   <fil_PH>Romansh localisation of Firefox ESR</fil_PH>
   <fi>Romansh localisation of Firefox ESR</fi>
   <fr_BE>Romansh localisation of Firefox ESR</fr_BE>
   <fr>Localisation en romanche (Suisse - Grisons) pour Firefox ESR</fr>
   <gl_ES>Romansh localisation of Firefox ESR</gl_ES>
   <he_IL>Romansh localisation of Firefox ESR</he_IL>
   <hi>Romansh localisation of Firefox ESR</hi>
   <hr>Romansh localisation of Firefox ESR</hr>
   <hu>Romansh localisation of Firefox ESR</hu>
   <id>Romansh localisation of Firefox ESR</id>
   <is>Romansh localisation of Firefox ESR</is>
   <it>Romansh localisation of Firefox ESR</it>
   <ja>ロマンシュ語版 Firefox ESR</ja>
   <kk>Romansh localisation of Firefox ESR</kk>
   <ko>Romansh localisation of Firefox ESR</ko>
   <lt>Romansh localisation of Firefox ESR</lt>
   <mk>Romansh localisation of Firefox ESR</mk>
   <mr>Romansh localisation of Firefox ESR</mr>
   <nb_NO>Romansh localisation of Firefox ESR</nb_NO>
   <nb>Romansh lokaltilpassing av Firefox ESR</nb>
   <nl_BE>Romansh localisation of Firefox ESR</nl_BE>
   <nl>Romansh localisation of Firefox ESR</nl>
   <pl>Romansh localisation of Firefox ESR</pl>
   <pt_BR>Romanche Localização para o Firefox ESR</pt_BR>
   <pt>Romansh localisation of Firefox ESR</pt>
   <ro>Romansh localisation of Firefox ESR</ro>
   <ru>Romansh localisation of Firefox ESR</ru>
   <sk>Romansh localisation of Firefox ESR</sk>
   <sl>Romansh localisation of Firefox ESR</sl>
   <sq>Romansh localisation of Firefox ESR</sq>
   <sr>Romansh localisation of Firefox ESR</sr>
   <sv>Romansk lokalisering av Firefox ESR</sv>
   <th>Romansh localisation of Firefox ESR</th>
   <tr>Romansh localisation of Firefox ESR</tr>
   <uk>Romansh localisation of Firefox ESR</uk>
   <vi>Romansh localisation of Firefox ESR</vi>
   <zh_CN>Romansh localisation of Firefox ESR</zh_CN>
   <zh_HK>Romansh localisation of Firefox ESR</zh_HK>
   <zh_TW>Romansh localisation of Firefox ESR</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
firefox-esr-l10n-rm
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
firefox-esr-l10n-rm
</uninstall_package_names>

</app>

==> packageinstaller-pkglist_0.3.32.tar.xz: packageinstaller-pkglist/Romansh_Default_Firefox_esr.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Romansh_Default_Firefox_esr
</name>

<description>
   <am>Romansh localisation of Firefox ESR</am>
   <ar>Romansh localisation of Firefox ESR</ar>
   <be>Romansh localisation of Firefox ESR</be>
   <bg>Romansh localisation of Firefox ESR</bg>
   <bn>Romansh localisation of Firefox ESR</bn>
   <ca>Romansh localisation of Firefox ESR</ca>
   <cs>Romansh localisation of Firefox ESR</cs>
   <da>Romansh localisation of Firefox ESR</da>
   <de>Schweizerische Lokalisation für die Sprache “Rätoromanisch” von “Firefox ESR”</de>
   <el>Romansh για Firefox ESR</el>
   <en>Romansh localisation of Firefox ESR</en>
   <es_ES>Localización Romanche de Firefox ESR</es_ES>
   <es>Localización Romanche de Firefox ESR</es>
   <et>Romansh localisation of Firefox ESR</et>
   <eu>Romansh localisation of Firefox ESR</eu>
   <fa>Romansh localisation of Firefox ESR</fa>
   <fil_PH>Romansh localisation of Firefox ESR</fil_PH>
   <fi>Romansh localisation of Firefox ESR</fi>
   <fr_BE>Romansh localisation of Firefox ESR</fr_BE>
   <fr>Localisation en romanche (Suisse - Grisons) pour Firefox ESR</fr>
   <gl_ES>Romansh localisation of Firefox ESR</gl_ES>
   <gu>Romansh localisation of Firefox ESR</gu>
   <he_IL>Romansh localisation of Firefox ESR</he_IL>
   <hi>Romansh localisation of Firefox ESR</hi>
   <hr>Romansh localisation of Firefox ESR</hr>
   <hu>Romansh localisation of Firefox ESR</hu>
   <id>Romansh localisation of Firefox ESR</id>
   <is>Romansh localisation of Firefox ESR</is>
   <it>Localizzazione in romancio di Firefox ESR</it>
   <ja>ロマンシュ語版 Firefox ESR</ja>
   <kk>Romansh localisation of Firefox ESR</kk>
   <ko>Romansh localisation of Firefox ESR</ko>
   <lt>Romansh localisation of Firefox ESR</lt>
   <mk>Romansh localisation of Firefox ESR</mk>
   <mr>Romansh localisation of Firefox ESR</mr>
   <nb_NO>Romansh localisation of Firefox ESR</nb_NO>
   <nb>Romansh lokaltilpassing av Firefox ESR</nb>
   <nl_BE>Romansh localisation of Firefox ESR</nl_BE>
   <nl>Romansh localisation of Firefox ESR</nl>
   <pl>Romansh localisation of Firefox ESR</pl>
   <pt_BR>Romanche Localização para o Firefox ESR</pt_BR>
   <pt>Romansh localisation of Firefox ESR</pt>
   <ro>Romansh localisation of Firefox ESR</ro>
   <ru>Romansh localisation of Firefox ESR</ru>
   <sk>Romansh localisation of Firefox ESR</sk>
   <sl>Romansh localisation of Firefox ESR</sl>
   <sq>Romansh localisation of Firefox ESR</sq>
   <sr>Romansh localisation of Firefox ESR</sr>
   <sv>Romansk lokalisering av Firefox ESR</sv>
   <th>Romansh localisation of Firefox ESR</th>
   <tr>Romansh localisation of Firefox ESR</tr>
   <uk>Romansh localisation of Firefox ESR</uk>
   <vi>Romansh localisation of Firefox ESR</vi>
   <zh_CN>Romansh localisation of Firefox ESR</zh_CN>
   <zh_HK>Romansh localisation of Firefox ESR</zh_HK>
   <zh_TW>Romansh localisation of Firefox ESR</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
firefox-esr-l10n-rm
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
firefox-esr-l10n-rm
</uninstall_package_names>

</app>
